# OriginalRelpath


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------

## Example

```python
from bia_integrator_api.models.original_relpath import OriginalRelpath

# TODO update the JSON string below
json = "{}"
# create an instance of OriginalRelpath from a JSON string
original_relpath_instance = OriginalRelpath.from_json(json)
# print the JSON string representation of the object
print OriginalRelpath.to_json()

# convert the object into a dict
original_relpath_dict = original_relpath_instance.to_dict()
# create an instance of OriginalRelpath from a dict
original_relpath_form_dict = original_relpath.from_dict(original_relpath_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


